upsert_block_header

Function upsert_block_header 

pub fn upsert_block_header(
    conn: &mut SqliteConnection,
    header: &BlockHeader,
) -> Result<(), DatabaseError>
Upserts a block header into the database.

Inserts a new row if no block header exists at the given block number, or replaces the existing block header if one already exists.