ValidatorSigner

Enum ValidatorSigner 

pub enum ValidatorSigner {
    Kms(KmsSigner),
    Local(SecretKey),
}
Signer that the Validator uses to sign blocks.

Variants

Implementations

Source

impl ValidatorSigner

pub async fn new_kms(key_id: impl Into<String>) -> Result<Self>

Constructs a signer which uses an AWS KMS key for signing.

See KmsSigner for details as to env var configuration and AWS IAM policies required to use this functionality.

pub fn new_local(secret_key: SecretKey) -> Self

Constructs a signer which uses a local secret key for signing.

pub async fn sign(&self, header: &BlockHeader) -> Result<Signature>

Signs a block header using the configured signer.